# -*- coding: utf-8 -*-
from prettytable import PrettyTable

from tikit.tencentcloud.tione.v20211111 import models


def framework_table(framework_response):
    """

    :param framework_response:
    :type framework_response:   :class:`tikit.tencentcloud.tione.v20211111.models.DescribeTrainingFrameworksResponse`
    :return:
    :rtype:
    """
    table = PrettyTable()
    table.field_names = [
        "框架名称",
        "版本",
        "训练模式"
    ]
    for framework in framework_response.FrameworkInfos:
        for framework_version in framework.VersionInfos:
            table.add_row([
                framework.Name,
                "".join(framework_version.Version),
                ", ".join(framework_version.TrainingModes)
            ])
    table.align = 'l'
    return table


def framework_str(self):
    return framework_table(self).get_string()


def framework_html(self):
    return framework_table(self).get_html_string()


def bill_specs_table(bill_specs_response):
    """

    :param bill_specs_response:
    :type bill_specs_response:   :class:`tikit.tencentcloud.tione.v20211111.models.DescribeBillingSpecsResponse`
    :return:
    :rtype:
    """
    table = PrettyTable()
    table.field_names = [
        "配置名称",
        "描述",
        "每小时价格（单位：元）"
    ]
    for spec in bill_specs_response.Specs:
        table.add_row([
            spec.SpecName,
            spec.SpecAlias,
            spec.SpecId
        ])
    return table


def bill_specs_str(self):
    return bill_specs_table(self).get_string()


def bill_specs_html(self):
    return bill_specs_table(self).get_html_string()


def training_task_table(training_task_response):
    """

    :param training_task_response:
    :type training_task_response:   :class:`tikit.tencentcloud.tione.v20211111.models.DescribeTrainingTasksResponse`
    :return:
    :rtype:
    """
    paid_dict = {
        "PREPAID": "预付费",
        "POSTPAID_BY_HOUR": "后付费"
    }
    table = PrettyTable()
    table.field_names = [
        "任务ID",
        "名称",
        "训练框架",
        "训练模式",
        "计费模式",
        "标签",
        "状态",
        "运行时长",
        "训练开始时间"
    ]
    for task in training_task_response.TrainingTaskSet:
        if task.RuntimeInSeconds > 86400:
            time_str = "{}天{}小时{}分{}秒".format(int(task.RuntimeInSeconds / 86400),
                                              int((task.RuntimeInSeconds % 86400) / 3600),
                                              int((task.RuntimeInSeconds % 3600) / 60),
                                              task.RuntimeInSeconds % 60)
        elif task.RuntimeInSeconds > 3600:
            time_str = "{}小时{}分{}秒".format(int(task.RuntimeInSeconds / 3600),
                                           int((task.RuntimeInSeconds % 3600) / 60),
                                           task.RuntimeInSeconds % 60)
        else:
            time_str = "{}分{}秒".format(int(task.RuntimeInSeconds / 60), task.RuntimeInSeconds % 60)
        if len(task.FrameworkName) > 0:
            framework = "{}:{}".format(task.FrameworkName, task.FrameworkVersion)
        else:
            framework = "CUSTOM"  # TODO
        table.add_row([
            task.Id,
            task.Name,
            framework,
            task.TrainingMode,
            paid_dict[task.ChargeType],
            "\n".join(map(lambda x: "%s:%s" % (x.TagKey, x.TagValue), task.Tags)),
            task.Status,
            time_str,
            task.StartTime
        ])
    return table


def training_task_str(self):
    return training_task_table(self).get_string()


def training_task_html(self):
    return training_task_table(self).get_html_string()


def log_table(log_response):
    """

    :param log_response:
    :type log_response:   :class:`tikit.tencentcloud.tione.v20211111.models.DescribeLogsResponse`
    :return:
    :rtype:
    """
    table = PrettyTable()
    table.field_names = [
        "日志时间",
        "实例名称",
        "日志数据"
    ]
    for one_log in log_response.Content:
        table.add_row([
            one_log.Timestamp,
            one_log.PodName,
            one_log.Message
        ])
    table.align = 'l'
    return table


def log_str(self):
    return log_table(self).get_string()


def log_html(self):
    return log_table(self).get_html_string()


models.DescribeTrainingFrameworksResponse.__repr__ = framework_str
models.DescribeTrainingFrameworksResponse._repr_html_ = framework_html

models.DescribeBillingSpecsResponse.__repr__ = bill_specs_str
models.DescribeBillingSpecsResponse._repr_html_ = bill_specs_html

models.DescribeTrainingTasksResponse.__repr__ = training_task_str
models.DescribeTrainingTasksResponse._repr_html_ = training_task_html

models.DescribeLogsResponse.__repr__ = log_str
models.DescribeLogsResponse._repr_html_ = log_html



# -*- coding: utf-8 -*-
from prettytable import PrettyTable

from tikit.tencentcloud.tione.v20211111 import models


def dataset_table(dataset_response):
    """

    :param dataset_response:
    :type dataset_response:   :class:`tikit.tencentcloud.tione.v20211111.models.DescribeDatasetsResponse`
    :return:
    :rtype:
    """
    type_dict = {
        "TYPE_DATASET_TEXT": "文本",
        "TYPE_DATASET_TABLE": "表格",
        "TYPE_DATASET_IMAGE": "图片",
        "TYPE_DATASET_OTHER": "其他"
    }
    unit_dict = {
        "TYPE_DATASET_TEXT": "行",
        "TYPE_DATASET_TABLE": "行",
        "TYPE_DATASET_IMAGE": "张",
        "TYPE_DATASET_OTHER": "个"
    }
    table = PrettyTable()
    table.field_names = [
        "ID",
        "名称",
        "版本",
        "类型",
        "标签",
        "状态",
        "数据量",
        "源COS路径",
        "标签存储路径",
        "标注任务名称",
        "创建时间"
    ]
    for dataset in dataset_response.DatasetGroups:
        table.add_row([
            dataset.DatasetId,
            dataset.DatasetName,
            dataset.DatasetVersion,
            type_dict[dataset.DatasetType],
            "\n".join(map(lambda x: "%s:%s" % (x.TagKey, x.TagValue), dataset.DatasetTags)),
            dataset.DatasetStatus,
            "{}{}".format(dataset.FileNum, unit_dict[dataset.DatasetType]),
            dataset.StorageDataPath,
            dataset.StorageLabelPath,
            dataset.DatasetAnnotationTaskName,
            dataset.CreateTime
        ])
    return table


def dataset_str(self):
    return dataset_table(self).get_string()


def dataset_html(self):
    return dataset_table(self).get_html_string()


def detail_structured_table(detail_structured):
    """

    :param detail_structured:
    :type detail_structured:   :class:`tikit.tencentcloud.tione.v20211111.models.DescribeDatasetDetailStructuredResponse`
    :return:
    :rtype:
    """
    table = PrettyTable()
    table.field_names = detail_structured.ColumnNames
    for row_item in detail_structured.RowItems:
        row = []
        for column in table.field_names:
            field_value = ""
            for name_value in row_item.Values:
                if name_value.Name == column:
                    field_value = name_value.Value
                    break
            row.append(field_value)
        table.add_row(row)
    return table


def detail_structured_str(self):
    return detail_structured_table(self).get_string()


def detail_structured_html(self):
    return detail_structured_table(self).get_html_string()


def detail_unstructured_table(detail_unstructured):
    """

    :param detail_unstructured:
    :type detail_unstructured:   :class:`tikit.tencentcloud.tione.v20211111.models.DescribeDatasetDetailStructuredResponse`
    :return:
    :rtype:
    """
    table = PrettyTable()
    table.field_names = [
        "总量",
        "未标注",
        "已标注",
    ]
    table.add_row([
        detail_unstructured.FilterTotalCount,
        detail_unstructured.NonAnnotatedTotalCount,
        detail_unstructured.AnnotatedTotalCount
    ])
    return table


def detail_unstructured_str(self):
    return detail_unstructured_table(self).get_string()


def detail_unstructured_html(self):
    return detail_unstructured_table(self).get_html_string()


models.DescribeDatasetsResponse.__repr__ = dataset_str
models.DescribeDatasetsResponse._repr_html_ = dataset_html

models.DescribeDatasetDetailStructuredResponse.__repr__ = detail_structured_str
models.DescribeDatasetDetailStructuredResponse._repr_html_ = detail_structured_html

models.DescribeDatasetDetailUnstructuredResponse.__repr__ = detail_unstructured_str
models.DescribeDatasetDetailUnstructuredResponse._repr_html_ = detail_unstructured_html



#!/usr/bin/python
# -*- coding: utf-8 -*-

import os
import socket
import logging

try:
    from http.client import HTTPConnection, BadStatusLine, HTTPSConnection
    from urllib.parse import urlparse
except ImportError:
    from httplib import HTTPConnection, BadStatusLine, HTTPSConnection
    from urlparse import urlparse

from tikit.tencentcloud.common.exception.tencent_cloud_sdk_exception import TencentCloudSDKException


logger = logging.getLogger("tencentcloud_sdk_common")


def _get_proxy_from_env(host, varname="HTTPS_PROXY"):
    no_proxy = os.environ.get("NO_PROXY") or os.environ.get("no_proxy")
    if no_proxy and host in no_proxy:
        return None
    return os.environ.get(varname.lower()) or os.environ.get(varname.upper())


class ProxyHTTPSConnection(HTTPSConnection):
    def __init__(self, host, port=None, timeout=60, proxy=None):
        self.has_proxy = False
        self.request_host = host
        proxy = proxy or _get_proxy_from_env(host, varname="HTTPS_PROXY")
        if proxy:
            url = urlparse(proxy)
            if not url.hostname:
                url = urlparse('https://' + proxy)
            host = url.hostname
            port = url.port
            self.has_proxy = True
        HTTPSConnection.__init__(self, host, port, timeout=timeout)
        self.request_length = 0

    def send(self, astr):
        HTTPSConnection.send(self, astr)
        self.request_length += len(astr)

    def request(self, method, url, body=None, headers={}):
        self.request_length = 0
        if self.has_proxy:
            self.set_tunnel(self.request_host, 443)
        headers.setdefault("Host", self.request_host)
        HTTPSConnection.request(self, method, url, body, headers)


class ProxyHTTPConnection(HTTPConnection):
    def __init__(self, host, port=None, timeout=60, proxy=None):
        self.request_length = 0
        self.has_proxy = False
        self.request_host = host
        proxy = proxy or _get_proxy_from_env(host, varname="HTTP_PROXY")
        if proxy:
            url = urlparse(proxy)
            if not url.hostname:
                url = urlparse('http://' + proxy)
            host = url.hostname
            port = url.port
            self.has_proxy = True
        HTTPConnection.__init__(self, host, port, timeout=timeout)

    def request(self, method, url, body=None, headers={}):
        if self.has_proxy:
            self.set_tunnel(self.request_host, 80)
        headers.setdefault("Host", self.request_host)
        HTTPConnection.request(self, method, url, body, headers)


class ApiRequest(object):
    def __init__(self, host, req_timeout=60, debug=False, proxy=None, is_http=False):
        if is_http:
            self.conn = ProxyHTTPConnection(host, timeout=req_timeout, proxy=proxy)
        else:
            self.conn = ProxyHTTPSConnection(host, timeout=req_timeout, proxy=proxy)
        self.req_timeout = req_timeout
        self.keep_alive = False
        self.debug = debug
        self.request_size = 0
        self.response_size = 0

    def set_req_timeout(self, req_timeout):
        self.req_timeout = req_timeout

    def is_keep_alive(self):
        return self.keep_alive

    def set_keep_alive(self, flag=True):
        self.keep_alive = flag

    def set_debug(self, debug):
        self.debug = debug

    def _request(self, req_inter):
        if self.keep_alive:
            req_inter.header["Connection"] = "Keep-Alive"
        if self.debug:
            logger.debug("SendRequest %s" % req_inter)
        if req_inter.method == 'GET':
            req_inter_url = '%s?%s' % (req_inter.uri, req_inter.data)
            self.conn.request(req_inter.method, req_inter_url,
                              None, req_inter.header)
        elif req_inter.method == 'POST':
            self.conn.request(req_inter.method, req_inter.uri,
                              req_inter.data, req_inter.header)
        else:
            raise TencentCloudSDKException(
                "ClientParamsError", 'Method only support (GET, POST)')

    def send_request(self, req_inter):
        try:
            self._request(req_inter)
            try:
                http_resp = self.conn.getresponse()
            except BadStatusLine:
                # open another connection when keep-alive timeout
                # httplib will not handle keep-alive timeout,
                # so we must handle it ourself
                logger.error("keep-alive timeout, reopen connection")
                self.conn.close()
                self._request(req_inter)
                http_resp = self.conn.getresponse()
            headers = dict(http_resp.getheaders())
            resp_inter = ResponseInternal(status=http_resp.status,
                                          header=headers,
                                          data=http_resp.read())
            self.request_size = self.conn.request_length
            self.response_size = len(resp_inter.data)
            if not self.is_keep_alive():
                self.conn.close()
            logger.debug("GetResponse %s" % resp_inter)
            return resp_inter
        except Exception as e:
            self.conn.close()
            raise TencentCloudSDKException("ClientNetworkError", str(e))


class RequestInternal(object):
    def __init__(self, host="", method="", uri="", header=None, data=""):
        if header is None:
            header = {}
        self.host = host
        self.method = method
        self.uri = uri
        self.header = header
        self.data = data

    def __str__(self):
        headers = "\n".join("%s: %s" % (k, v) for k, v in self.header.items())
        return ("Host: %s\nMethod: %s\nUri: %s\nHeader: %s\nData: %s\n"
                % (self.host, self.method, self.uri, headers, self.data))


class ResponseInternal(object):
    def __init__(self, status=0, header=None, data=""):
        if header is None:
            header = {}
        self.status = status
        self.header = header
        self.data = data

    def __str__(self):
        headers = "\n".join("%s: %s" % (k, v) for k, v in self.header.items())
        return ("Status: %s\nHeader: %s\nData: %s\n"
                % (self.status, headers, self.data))



# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import json

from tikit.tencentcloud.common.exception.tencent_cloud_sdk_exception import TencentCloudSDKException
from tikit.tencentcloud.common.abstract_client import AbstractClient
from tikit.tencentcloud.tione.v20211111 import models


class TioneClient(AbstractClient):
    _apiVersion = '2021-11-11'
    _endpoint = 'tione.tencentcloudapi.com'
    _service = 'tione'


    def CreateDataset(self, request):
        """创建数据集

        :param request: Request instance for CreateDataset.
        :type request: :class:`tikit.tencentcloud.tione.v20211111.models.CreateDatasetRequest`
        :rtype: :class:`tikit.tencentcloud.tione.v20211111.models.CreateDatasetResponse`

        """
        try:
            params = request._serialize()
            body = self.call("CreateDataset", params)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.CreateDatasetResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def CreateTrainingModel(self, request):
        """导入模型

        :param request: Request instance for CreateTrainingModel.
        :type request: :class:`tikit.tencentcloud.tione.v20211111.models.CreateTrainingModelRequest`
        :rtype: :class:`tikit.tencentcloud.tione.v20211111.models.CreateTrainingModelResponse`

        """
        try:
            params = request._serialize()
            body = self.call("CreateTrainingModel", params)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.CreateTrainingModelResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def CreateTrainingTask(self, request):
        """创建模型训练任务

        :param request: Request instance for CreateTrainingTask.
        :type request: :class:`tikit.tencentcloud.tione.v20211111.models.CreateTrainingTaskRequest`
        :rtype: :class:`tikit.tencentcloud.tione.v20211111.models.CreateTrainingTaskResponse`

        """
        try:
            params = request._serialize()
            body = self.call("CreateTrainingTask", params)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.CreateTrainingTaskResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def DeleteDataset(self, request):
        """删除数据集

        :param request: Request instance for DeleteDataset.
        :type request: :class:`tikit.tencentcloud.tione.v20211111.models.DeleteDatasetRequest`
        :rtype: :class:`tikit.tencentcloud.tione.v20211111.models.DeleteDatasetResponse`

        """
        try:
            params = request._serialize()
            body = self.call("DeleteDataset", params)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.DeleteDatasetResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def DeleteTrainingModel(self, request):
        """删除模型

        :param request: Request instance for DeleteTrainingModel.
        :type request: :class:`tikit.tencentcloud.tione.v20211111.models.DeleteTrainingModelRequest`
        :rtype: :class:`tikit.tencentcloud.tione.v20211111.models.DeleteTrainingModelResponse`

        """
        try:
            params = request._serialize()
            body = self.call("DeleteTrainingModel", params)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.DeleteTrainingModelResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def DeleteTrainingModelVersion(self, request):
        """删除模型版本

        :param request: Request instance for DeleteTrainingModelVersion.
        :type request: :class:`tikit.tencentcloud.tione.v20211111.models.DeleteTrainingModelVersionRequest`
        :rtype: :class:`tikit.tencentcloud.tione.v20211111.models.DeleteTrainingModelVersionResponse`

        """
        try:
            params = request._serialize()
            body = self.call("DeleteTrainingModelVersion", params)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.DeleteTrainingModelVersionResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def DeleteTrainingTask(self, request):
        """删除训练任务

        :param request: Request instance for DeleteTrainingTask.
        :type request: :class:`tikit.tencentcloud.tione.v20211111.models.DeleteTrainingTaskRequest`
        :rtype: :class:`tikit.tencentcloud.tione.v20211111.models.DeleteTrainingTaskResponse`

        """
        try:
            params = request._serialize()
            body = self.call("DeleteTrainingTask", params)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.DeleteTrainingTaskResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def DescribeBillingResourceGroups(self, request):
        """查询资源组详情

        :param request: Request instance for DescribeBillingResourceGroups.
        :type request: :class:`tikit.tencentcloud.tione.v20211111.models.DescribeBillingResourceGroupsRequest`
        :rtype: :class:`tikit.tencentcloud.tione.v20211111.models.DescribeBillingResourceGroupsResponse`

        """
        try:
            params = request._serialize()
            body = self.call("DescribeBillingResourceGroups", params)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.DescribeBillingResourceGroupsResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def DescribeBillingSpecs(self, request):
        """本接口(DescribeBillingSpecs)用于查询计费项列表

        :param request: Request instance for DescribeBillingSpecs.
        :type request: :class:`tikit.tencentcloud.tione.v20211111.models.DescribeBillingSpecsRequest`
        :rtype: :class:`tikit.tencentcloud.tione.v20211111.models.DescribeBillingSpecsResponse`

        """
        try:
            params = request._serialize()
            body = self.call("DescribeBillingSpecs", params)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.DescribeBillingSpecsResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def DescribeBillingSpecsPrice(self, request):
        """本接口(DescribeBillingSpecsPrice)用于查询计费项价格。

        :param request: Request instance for DescribeBillingSpecsPrice.
        :type request: :class:`tikit.tencentcloud.tione.v20211111.models.DescribeBillingSpecsPriceRequest`
        :rtype: :class:`tikit.tencentcloud.tione.v20211111.models.DescribeBillingSpecsPriceResponse`

        """
        try:
            params = request._serialize()
            body = self.call("DescribeBillingSpecsPrice", params)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.DescribeBillingSpecsPriceResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def DescribeDatasetDetailStructured(self, request):
        """查询结构化数据集详情

        :param request: Request instance for DescribeDatasetDetailStructured.
        :type request: :class:`tikit.tencentcloud.tione.v20211111.models.DescribeDatasetDetailStructuredRequest`
        :rtype: :class:`tikit.tencentcloud.tione.v20211111.models.DescribeDatasetDetailStructuredResponse`

        """
        try:
            params = request._serialize()
            body = self.call("DescribeDatasetDetailStructured", params)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.DescribeDatasetDetailStructuredResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def DescribeDatasetDetailUnstructured(self, request):
        """查询非结构化数据集详情

        :param request: Request instance for DescribeDatasetDetailUnstructured.
        :type request: :class:`tikit.tencentcloud.tione.v20211111.models.DescribeDatasetDetailUnstructuredRequest`
        :rtype: :class:`tikit.tencentcloud.tione.v20211111.models.DescribeDatasetDetailUnstructuredResponse`

        """
        try:
            params = request._serialize()
            body = self.call("DescribeDatasetDetailUnstructured", params)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.DescribeDatasetDetailUnstructuredResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def DescribeDatasets(self, request):
        """查询数据集列表

        :param request: Request instance for DescribeDatasets.
        :type request: :class:`tikit.tencentcloud.tione.v20211111.models.DescribeDatasetsRequest`
        :rtype: :class:`tikit.tencentcloud.tione.v20211111.models.DescribeDatasetsResponse`

        """
        try:
            params = request._serialize()
            body = self.call("DescribeDatasets", params)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.DescribeDatasetsResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def DescribeInferTemplates(self, request):
        """查询推理镜像模板

        :param request: Request instance for DescribeInferTemplates.
        :type request: :class:`tikit.tencentcloud.tione.v20211111.models.DescribeInferTemplatesRequest`
        :rtype: :class:`tikit.tencentcloud.tione.v20211111.models.DescribeInferTemplatesResponse`

        """
        try:
            params = request._serialize()
            body = self.call("DescribeInferTemplates", params)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.DescribeInferTemplatesResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def DescribeLatestTrainingMetrics(self, request):
        """查询最近上报的训练自定义指标

        :param request: Request instance for DescribeLatestTrainingMetrics.
        :type request: :class:`tikit.tencentcloud.tione.v20211111.models.DescribeLatestTrainingMetricsRequest`
        :rtype: :class:`tikit.tencentcloud.tione.v20211111.models.DescribeLatestTrainingMetricsResponse`

        """
        try:
            params = request._serialize()
            body = self.call("DescribeLatestTrainingMetrics", params)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.DescribeLatestTrainingMetricsResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def DescribeLogs(self, request):
        """获取训练、推理、Notebook服务的日志

        :param request: Request instance for DescribeLogs.
        :type request: :class:`tikit.tencentcloud.tione.v20211111.models.DescribeLogsRequest`
        :rtype: :class:`tikit.tencentcloud.tione.v20211111.models.DescribeLogsResponse`

        """
        try:
            params = request._serialize()
            body = self.call("DescribeLogs", params)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.DescribeLogsResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def DescribeTrainingFrameworks(self, request):
        """训练框架列表

        :param request: Request instance for DescribeTrainingFrameworks.
        :type request: :class:`tikit.tencentcloud.tione.v20211111.models.DescribeTrainingFrameworksRequest`
        :rtype: :class:`tikit.tencentcloud.tione.v20211111.models.DescribeTrainingFrameworksResponse`

        """
        try:
            params = request._serialize()
            body = self.call("DescribeTrainingFrameworks", params)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.DescribeTrainingFrameworksResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def DescribeTrainingMetrics(self, request):
        """查询训练自定义指标

        :param request: Request instance for DescribeTrainingMetrics.
        :type request: :class:`tikit.tencentcloud.tione.v20211111.models.DescribeTrainingMetricsRequest`
        :rtype: :class:`tikit.tencentcloud.tione.v20211111.models.DescribeTrainingMetricsResponse`

        """
        try:
            params = request._serialize()
            body = self.call("DescribeTrainingMetrics", params)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.DescribeTrainingMetricsResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def DescribeTrainingModelVersion(self, request):
        """查询模型版本

        :param request: Request instance for DescribeTrainingModelVersion.
        :type request: :class:`tikit.tencentcloud.tione.v20211111.models.DescribeTrainingModelVersionRequest`
        :rtype: :class:`tikit.tencentcloud.tione.v20211111.models.DescribeTrainingModelVersionResponse`

        """
        try:
            params = request._serialize()
            body = self.call("DescribeTrainingModelVersion", params)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.DescribeTrainingModelVersionResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def DescribeTrainingModelVersions(self, request):
        """模型版本列表

        :param request: Request instance for DescribeTrainingModelVersions.
        :type request: :class:`tikit.tencentcloud.tione.v20211111.models.DescribeTrainingModelVersionsRequest`
        :rtype: :class:`tikit.tencentcloud.tione.v20211111.models.DescribeTrainingModelVersionsResponse`

        """
        try:
            params = request._serialize()
            body = self.call("DescribeTrainingModelVersions", params)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.DescribeTrainingModelVersionsResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def DescribeTrainingModels(self, request):
        """模型列表

        :param request: Request instance for DescribeTrainingModels.
        :type request: :class:`tikit.tencentcloud.tione.v20211111.models.DescribeTrainingModelsRequest`
        :rtype: :class:`tikit.tencentcloud.tione.v20211111.models.DescribeTrainingModelsResponse`

        """
        try:
            params = request._serialize()
            body = self.call("DescribeTrainingModels", params)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.DescribeTrainingModelsResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def DescribeTrainingTask(self, request):
        """训练任务详情

        :param request: Request instance for DescribeTrainingTask.
        :type request: :class:`tikit.tencentcloud.tione.v20211111.models.DescribeTrainingTaskRequest`
        :rtype: :class:`tikit.tencentcloud.tione.v20211111.models.DescribeTrainingTaskResponse`

        """
        try:
            params = request._serialize()
            body = self.call("DescribeTrainingTask", params)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.DescribeTrainingTaskResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def DescribeTrainingTaskPods(self, request):
        """训练任务pod列表

        :param request: Request instance for DescribeTrainingTaskPods.
        :type request: :class:`tikit.tencentcloud.tione.v20211111.models.DescribeTrainingTaskPodsRequest`
        :rtype: :class:`tikit.tencentcloud.tione.v20211111.models.DescribeTrainingTaskPodsResponse`

        """
        try:
            params = request._serialize()
            body = self.call("DescribeTrainingTaskPods", params)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.DescribeTrainingTaskPodsResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def DescribeTrainingTasks(self, request):
        """训练任务列表

        :param request: Request instance for DescribeTrainingTasks.
        :type request: :class:`tikit.tencentcloud.tione.v20211111.models.DescribeTrainingTasksRequest`
        :rtype: :class:`tikit.tencentcloud.tione.v20211111.models.DescribeTrainingTasksResponse`

        """
        try:
            params = request._serialize()
            body = self.call("DescribeTrainingTasks", params)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.DescribeTrainingTasksResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def PushTrainingMetrics(self, request):
        """上报训练自定义指标

        :param request: Request instance for PushTrainingMetrics.
        :type request: :class:`tikit.tencentcloud.tione.v20211111.models.PushTrainingMetricsRequest`
        :rtype: :class:`tikit.tencentcloud.tione.v20211111.models.PushTrainingMetricsResponse`

        """
        try:
            params = request._serialize()
            body = self.call("PushTrainingMetrics", params)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.PushTrainingMetricsResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def StopTrainingTask(self, request):
        """停止模型训练任务

        :param request: Request instance for StopTrainingTask.
        :type request: :class:`tikit.tencentcloud.tione.v20211111.models.StopTrainingTaskRequest`
        :rtype: :class:`tikit.tencentcloud.tione.v20211111.models.StopTrainingTaskResponse`

        """
        try:
            params = request._serialize()
            body = self.call("StopTrainingTask", params)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.StopTrainingTaskResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


# -*- coding: utf-8 -*-
import os
import random
import string
import csv

from pyhive import hive
from hdfs import Client as HdfsClient


def _get_tmp_path():
    """
    返回随机生成的hdfs临时目录
    :return:    临时目录
    :rtype:     str
    """
    folder = "".join(random.sample(string.ascii_letters + string.digits, random.randint(12, 20)))
    return "/tmp/tikit/%s" % folder


def _get_host_port(server):
    """
    把服务地址解析成主机地址和端口
    :param server:  服务地址
    :type server:   str
    :return:        主机地址和端口
    :rtype:         list
    """
    parts = server.split(":")
    if len(parts) != 2:
        raise Exception('invalid hive_server, should like "10.0.0.1:7001"')
    return parts


def upload_to_hive_by_hdfs(local_path, hdfs_url, hive_server, table_name, database="default", auth="CUSTOM", username=None,
                   password=None, overwrite=False, partition=""):
    """把本地文件的数据导入到hive表中，hdfs作为中间存储。
    过程：先把本地文件上传到hdfs上，然后再从hdfs文件导入到hive中。

    :param local_path:      本地文件或者文件夹。文件夹中不能包含子文件夹。
    :type local_path:       str
    :param hdfs_url:        webhdfs的url，如：http://10.0.3.16:4008
    :type hdfs_url:         str
    :param hive_server:     HiveServer2的地址
    :type hive_server:      str
    :param table_name:      Hive表的名称
    :type table_name:       str
    :param database:        数据库名称
    :type database:         str
    :param auth:            认证的方式
    :type auth:             str
    :param username:        数据库认证的用户名
    :type username:         str
    :param password:        数据库认证的密码
    :type password:         str
    :param overwrite:       是否删掉原来的数据
    :type overwrite:        bool
    :param partition:       分区的选择
    :type partition:        str
    :return:
    :rtype:
    """
    hdfs_path = hdfs_tmp_path = _get_tmp_path()
    hdfs_client = HdfsClient(hdfs_url)
    # 上传文件到一个不存在的目录（斜杠结尾）的时候，hdfs库会把目录当成最终文件
    if os.path.isfile(local_path):
        hdfs_path = os.path.join(hdfs_path, os.path.basename(local_path))
    hdfs_client.upload(hdfs_path, local_path)
    try:
        insert_hdfs_into_hive(hdfs_path, hive_server, table_name, database, auth, username,
                              password, overwrite, partition)
    finally:
        hdfs_client.delete(hdfs_tmp_path, True)


def insert_hdfs_into_hive(hdfs_path, hive_server, table_name, database="default", auth="CUSTOM", username=None,
                          password=None, overwrite=False, partition=""):
    """把hdfs的文件数据导入到hive表中。

    :param hdfs_path:       hdfs上的文件或者文件夹。文件夹中不能包含子文件夹。如：/tmp/file.csv
    :type hdfs_path:        str
    :param hdfs_url:        webhdfs的url，如：http://10.0.3.16:4008
    :type hdfs_url:         str
    :param hive_server:     HiveServer2的地址
    :type hive_server:      str
    :param table_name:      Hive表的名称
    :type table_name:       str
    :param database:        数据库名称
    :type database:         str
    :param auth:            认证的方式
    :type auth:             str
    :param username:        数据库认证的用户名
    :type username:         str
    :param password:        数据库认证的密码
    :type password:         str
    :param overwrite:       是否删掉原来的数据
    :type overwrite:        bool
    :param partition:       分区的选择
    :type partition:        str
    :return:
    :rtype:
    """
    hive_host, hive_port = _get_host_port(hive_server)
    with hive.Connection(host=hive_host, port=hive_port, database=database,
                         username=username, password=password, auth=auth) as conn:
        with conn.cursor() as cursor:
            sql = "LOAD DATA INPATH '{}' {} INTO TABLE {} {}".format(
                hdfs_path,
                "OVERWRITE" if overwrite else "",
                table_name,
                "" if partition == "" else "PARTITION (%s)" % partition
            )
            cursor.execute(sql)


# def export_csv_from_hive(local_path, hive_server, table_name="", sql="", database="default", auth="CUSTOM",
#                          username=None, password=None):
#     """把hive表的数据读出，写到本地的csv文件
#
#     :param local_path:      本地文件或者文件夹。文件夹中不能包含子文件夹。
#     :type local_path:       str
#     :param hive_server:     HiveServer2的地址
#     :type hive_server:      str
#     :param table_name:      Hive表的名称。sql设置时忽略此参数
#     :type table_name:       str
#     :param sql:             查数据sql语句。如：select * from t1
#     :type sql:              str
#     :param database:        数据库名称
#     :type database:         str
#     :param auth:            认证的方式
#     :type auth:             str
#     :param username:        数据库认证的用户名
#     :type username:         str
#     :param password:        数据库认证的密码
#     :type password:         str
#     :return:
#     :rtype:
#     """
#     if local_path.endswith("/") or os.path.isdir(local_path):
#         local_path = os.path.join(local_path, "result.csv")
#     if os.path.exists(local_path):
#         raise Exception('"%s" is already existed' % local_path)
#     local_dir = os.path.dirname(local_path)
#     if local_dir != "" and not os.path.exists(local_dir):
#         os.makedirs(local_dir)
#     # 支持table_name、sql两种方式，sql优先
#     if table_name == "" and sql == "":
#         raise Exception('"table_name" and "sql" cannot both be empty')
#     if sql == "":
#         sql = "SELECT * FROM %s" % table_name
#     # 读出表内容，写入到文件
#     hive_host, hive_port = _get_host_port(hive_server)
#     with hive.Connection(host=hive_host, port=hive_port, database=database,
#                          username=username, password=password, auth=auth) as conn:
#         with conn.cursor() as cursor, open(local_path, 'w') as f:
#             writer = csv.writer(f)
#             cursor.execute(sql)
#             # 测试过使用 cursor.fetchmany(10000)的方式，性能更差（1000万条数据，183M）
#             for row in cursor:
#                 writer.writerow(row)
#     return local_path


def export_from_hive_by_hdfs(local_path, hdfs_url, hive_server, table_name="", sql="", database="default",
                             auth="CUSTOM", username=None, password=None,
                             row_format="row format delimited fields terminated by ','"):
    """导出hive表到本地上，hdfs作为中间存储。对于大文件，这种方式比直接从hive表写到本地的效率更高。
    过程：先把hive导出到hdfs上，然后再从hdfs下载文件到本地。

    :param local_path:      本地的目录
    :type local_path:       str
    :param hdfs_url:        webhdfs的url，如：http://10.0.3.16:4008
    :type hdfs_url:         str
    :param hive_server:     HiveServer2的地址
    :type hive_server:      str
    :param table_name:      Hive表的名称。sql设置时忽略此参数
    :type table_name:       str
    :param sql:             查数据sql语句。如：select * from t1
    :type sql:              str
    :param database:        数据库名称
    :type database:         str
    :param auth:            认证的方式
    :type auth:             str
    :param username:        数据库认证的用户名
    :type username:         str
    :param password:        数据库认证的密码
    :type password:         str
    :param row_format:      行的输出格式
    :type row_format:       str
    :return:
    :rtype:
    """
    if os.path.isfile(local_path):
        raise Exception('"local_path" cannot be file')
    tmp_path = _get_tmp_path()
    hdfs_path = os.path.join(tmp_path, "result")
    hdfs_client = HdfsClient(hdfs_url)
    save_hive_to_hdfs(hdfs_path, hive_server, table_name, sql, database, auth, username, password, row_format)
    try:
        local_dir = os.path.dirname(local_path)
        if local_dir != "" and not os.path.exists(local_dir):
            os.makedirs(local_dir)
        return hdfs_client.download(hdfs_path, local_path)
    finally:
        hdfs_client.delete(hdfs_path, True)


def save_hive_to_hdfs(hdfs_path, hive_server, table_name="", sql="", database="default", auth="CUSTOM",
                      username=None, password=None, row_format="row format delimited fields terminated by ','"):
    """把hive表的数据导出到hdfs上

    :param hdfs_path:       目标hdfs的保存路径
    :type hdfs_path:        str
    :param hive_server:     HiveServer2的地址
    :type hive_server:      str
    :param table_name:      Hive表的名称。sql设置时忽略此参数
    :type table_name:       str
    :param sql:             查数据sql语句。如：select * from t1
    :type sql:              str
    :param database:        数据库名称
    :type database:         str
    :param auth:            认证的方式
    :type auth:             str
    :param username:        数据库认证的用户名
    :type username:         str
    :param password:        数据库认证的密码
    :type password:         str
    :param row_format:      行的输出格式
    :type row_format:       str
    :return:
    :rtype:
    """
    if table_name == "" and sql == "":
        raise Exception('"table_name" and "sql" cannot both be empty')
    hive_host, hive_port = _get_host_port(hive_server)
    with hive.Connection(host=hive_host, port=hive_port, database=database,
                         username=username, password=password, auth=auth) as conn:
        with conn.cursor() as cursor:
            # INSERT OVERWRITE [LOCAL] DIRECTORY directory1 SELECT ... FROM ...
            if sql == "":
                execute_sql = "INSERT OVERWRITE DIRECTORY '{}' {} SELECT {} FROM {}".format(
                    hdfs_path,
                    row_format,
                    "*",
                    table_name
                )
                cursor.execute(execute_sql)
            else:
                execute_sql = "INSERT OVERWRITE DIRECTORY '{}' {} {}".format(
                    hdfs_path,
                    row_format,
                    sql
                )
                cursor.execute(execute_sql)
    return hdfs_path



# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


# CAM签名/鉴权错误。
AUTHFAILURE = 'AuthFailure'

# CAM系统异常。
AUTHFAILURE_CAMEXCEPTION = 'AuthFailure.CamException'

# 未授权操作。
AUTHFAILURE_UNAUTHORIZEDOPERATION = 'AuthFailure.UnauthorizedOperation'

# 操作失败。
FAILEDOPERATION = 'FailedOperation'

# 调用集群失败。
FAILEDOPERATION_CALLCLUSTERFAIL = 'FailedOperation.CallClusterFail'

# 尚未开通CLS日志服务，请开前往开通。
FAILEDOPERATION_CLSSERVICENOTACTIVED = 'FailedOperation.ClsServiceNotActived'

# 数据库执行错误。
FAILEDOPERATION_EXECDATABASEFAIL = 'FailedOperation.ExecDatabaseFail'

# 标签操作失败。
FAILEDOPERATION_EXECTAGFAIL = 'FailedOperation.ExecTagFail'

# 数据库查询错误。
FAILEDOPERATION_QUERYDATABASEFAIL = 'FailedOperation.QueryDatabaseFail'

# 内部错误。
INTERNALERROR = 'InternalError'

# cos client 内部错误。
INTERNALERROR_DCCOSCLIENTERR = 'InternalError.DCCosClientErr'

# 创建内部异步任务失败。
INTERNALERROR_DCCREATEASYNCTASKERROR = 'InternalError.DCCreateAsyncTaskError'

# 创建cos client 失败。
INTERNALERROR_DCCREATEUSERCOSCLIENTERR = 'InternalError.DCCreateUserCosClientErr'

# 数据仓库 rpc 内部错误。
INTERNALERROR_DCDATAREPORPCERR = 'InternalError.DCDatarepoRpcErr'

# 数据集状态未恢复。
INTERNALERROR_DCDATASETSTATUSNOTREADY = 'InternalError.DCDatasetStatusNotReady'

# 获取用户临时秘钥失败。
INTERNALERROR_DCGETUSERTEMPLATESECURITERR = 'InternalError.DCGetUserTemplateSecuritErr'

# 数据序列化错误。
INTERNALERROR_DCMARSHALDATAERR = 'InternalError.DCMarshalDataErr'

# 数据集获取文件内容异常。
INTERNALERROR_DCQUERYDATASETCONTENTERR = 'InternalError.DCQueryDatasetContentErr'

# 数据反序列化错误。
INTERNALERROR_DCUNMARSHALDATAERR = 'InternalError.DCUnmarshalDataErr'

# 参数错误。
INVALIDPARAMETER = 'InvalidParameter'

# 请求参数校验失败。
INVALIDPARAMETER_VALIDATEERROR = 'InvalidParameter.ValidateError'

# 参数取值错误。
INVALIDPARAMETERVALUE = 'InvalidParameterValue'

# 不支持的标注类型。
INVALIDPARAMETERVALUE_DCANNOTATIONTYPE = 'InvalidParameterValue.DCAnnotationType'

# 存储桶参数错误。
INVALIDPARAMETERVALUE_DCCOSPATHINFO = 'InvalidParameterValue.DCCosPathInfo'

# 数据集标注状态不匹配。
INVALIDPARAMETERVALUE_DCDATASETANNOTATIONNOTMATCH = 'InvalidParameterValue.DCDatasetAnnotationNotMatch'

# 数据集Id不存在。
INVALIDPARAMETERVALUE_DCDATASETIDNOTEXIST = 'InvalidParameterValue.DCDatasetIdNotExist'

# 数据集重名已存在。
INVALIDPARAMETERVALUE_DCDATASETNAMEEXIST = 'InvalidParameterValue.DCDatasetNameExist'

# 不支持的数据集类型。
INVALIDPARAMETERVALUE_DCDATASETTYPE = 'InvalidParameterValue.DCDatasetType'

# 不支持的过滤参数。
INVALIDPARAMETERVALUE_DCFILTERVALUES = 'InvalidParameterValue.DCFilterValues'

# 缺少参数错误。
MISSINGPARAMETER = 'MissingParameter'

# 未知参数错误。
UNKNOWNPARAMETER = 'UnknownParameter'

# 操作不支持。
UNSUPPORTEDOPERATION = 'UnsupportedOperation'
